Simulation data randomly sampled from the entire volume of a ball of the specified dimension (by default, 3-dimensional).
Value
Data frame with x, y, z columns containing the
coordinates of the points and color the RGB color.
Simulation data randomly sampled from the entire volume of a ball of the specified dimension (by default, 3-dimensional).
Data frame with x, y, z columns containing the
coordinates of the points and color the RGB color.