Skip to contents

2D circle data with uniform spacing from "How to Use t-SNE Effectively".

Usage

circle_data(n)

Arguments

n

Number of points per side.

Value

Data frame with x and y coordinates in the columns x and y respectively, and color in the color column.

Details

Creates a dataset where the points are located on the circumference of a circle of unit radius, where the angle subtended by the point at the center of the circle has been uniformly sampled. Each point has a color linearly mapped from the angle to a rainbow color scheme.

Examples

df <- circle_data(n = 50)