Skip to contents

Random points sampled from a cube, from "How to Use t-SNE Effectively".

Usage

cube_data(n, dim, color = "#003399")

Arguments

n

Number of points to sample.

dim

Dimension of the cube.

color

Color to apply to each point.

Value

Data frame with coordinates in the X1, X2 ... Xdim columns, and color in the color column.

Details

Create a dataset of the of points randomly sampled from a unit cube of the specified dimension.

Examples

df <- cube_data(n = 50, dim = 3)