Skip to contents

Downloads the 50,000 point 'Mammoth' dataset, a 3D point cloud of a mammoth skeleton.

Usage

download_mammoth50k(timeout = 1800)

Format

A data frame with 50,000 rows and 3 variables, X, Y, and Z. The source coordinate vectors are ordered Y, X, Z; this function reorders them to the canonical X, Y, Z order. The Z-coordinate is the "height", i.e. the height of the mammoth varies with Z.

For more information see https://pair-code.github.io/understanding-umap/.

Arguments

timeout

Minimum download timeout in seconds. The default is 30 minutes; a larger existing global R timeout is preserved.

Value

Data frame containing the Mammoth coordinates.

Details

Downloads a data frame containing the 50,000 3D coordinates of a mammoth skeleton, digitized by the Smithsonian Institution.

This dataset is from Understanding UMAP, based on work originally done by Max Noichl. 50,000 points were down-sampled from the raw data used by Max Noichl.

Note

Requires the rjson package to be installed.

Examples

if (FALSE) { # \dontrun{
mammoth <- download_mammoth50k()
# The mammoth in profile, facing left
plot(mammoth$X, mammoth$Z)
} # }