Skip to contents

Two long, linear clusters in 2D from "How to Use t-SNE Effectively".

Usage

long_cluster_data(n)

Arguments

n

Number of points to sample per cluster.

Value

Data frame with coordinates in the x, y columns, and color in the color column.

Details

Creates a 2D dataset where points are sampled from two long, linear, closely-separated clusters. Points are colored depending from which cluster they are sampled from.

Examples

df <- long_cluster_data(n = 50)