Skip to contents

Points related by mutually orthogonal steps, from "How to Use t-SNE Effectively".

Usage

ortho_curve(n)

Arguments

n

Number of points to sample.

Value

Data frame with coordinates in the X1, X2 ... Xn columns, and color in the color column.

Details

Creates N points from an N-dimensional space, where each point is related by a mutually orthogonal step. Coordinates from a triangular matrix, where the coordinates in the triangle are one, and are zero everywhere else. Points are linearly mapped from their row id to a rainbow color scheme.

Examples

df <- ortho_curve(n = 50)