Skip to contents

Clusters arranged in a circle from "How to Use t-SNE Effectively".

Usage

random_circle_cluster_data(n)

Arguments

n

Number of points to define the circle. These are then jittered as described in 'Details', so the total number of observations in the data frame will be 20 * n.

Value

Data frame with x and y coordinates in the columns x and y respectively, and color in the color column.

Details

Creates a dataset where the points are located on the circumference of a circle of unit radius via circle_data(), where the angle subtended by the point at the center of the circle has been uniformly sampled.

Each point is then replicated 20 times, with a slight perturbation to the original coordinate (using a normal distribution with a standard deviation of 0.1). Only the twenty jittered points are added to the data frame. Each point has a color linearly mapped from the angle of the original unjittered point to a rainbow color scheme.

Examples

df <- random_circle_cluster_data(n = 50)