Skip to contents

Simulation data from a random jump process, from "How to Use t-SNE Effectively".

Usage

random_jump(n, dim)

Arguments

n

Number of points to sample.

dim

Number of dimensions of the dataset.

Value

Data frame with coordinates in the X1, X2 ... Xn columns, and color in the color column.

Details

Creates a dataset similar to random_walk() but with additional gaussian noise added at each step. Points are linearly mapped from their position in the walk to a rainbow color scheme.

Examples

df <- random_jump(n = 100, dim = 100)