Skip to contents

Simulation data from a random walk process, from "How to Use t-SNE Effectively".

Usage

random_walk(n, dim)

Arguments

n

Number of points to sample.

dim

Number of dimensions of the dataset.

Value

Data frame with coordinates in the X1, X2 ... Xn columns, and color in the color column.

Details

Creates a dataset where the coordinate of each point is related to the previous point by a gaussian perturbation. Points are linearly mapped from their position in the walk to a rainbow color scheme.

Examples

df <- random_walk(n = 100, dim = 100)