Display a NORB object as an image pair.
Arguments
- df
A legacy NORB data frame or canonical image result.
- category
The category of the object, an integer from 0 to 4.
- instance
The instance in the category, an integer from 0 to 9.
- elevation
The elevation of the camera, an integer from 0 to 8, representing elevations of 30 to 70 degrees from the horizontal, in increments of 5 degrees.
- azimuth
The azimuth, an even integer from 0, 2, 4, ... to 34. Multiply by ten to get the value in degrees.
- lighting
The lighting condition, represened by an integer in the range 0-5.