Skip to contents

Data in a rough simplex from "How to Use t-SNE Effectively".

Usage

simplex_data(n, noise = 0.5, color = "#003399")

Arguments

n

Number of points (and hence dimensionality) of the simplex.

noise

Degree by which to perturb the points from their original locations. A normal distribution with the specified standard deviation is applied to the non-zero coordinate.

color

Color to apply to each point.

Value

Data frame with coordinates in the X1, X2 ... Xn columns, and color in the color column.

Details

Create a dataset of the specified number of points arranged in a rough simplex, which also determines the dimensionality of the dataset. Each point has a single non-zero coordinate in a different column to all the other points.

Examples

df <- simplex_data(n = 50)