Skip to contents

Three gaussian clusters with equal size and bandwidth from "How to Use t-SNE Effectively".

Usage

three_clusters_data(n, dim = 50)

Arguments

n

Number of points per gaussian.

dim

Dimension of the gaussians.

Value

Data frame with coordinates in the X1, X2 ... Xdim columns, and color in the color column.

Details

Creates a dataset consisting of three symmetric gaussian distributions with equal number of points and standard deviation 1. The clusters are arranged in a line, with the second cluster 10 units from the first, and the third cluster 50 units from the first. Points are colored depending on which cluster they belong to.

Examples

df <- three_clusters_data(n = 50, dim = 2)