Two gaussians with equal size and bandwidth, from "How to Use t-SNE Effectively".
Details
Creates a dataset consisting of two symmetric gaussian distributions with equal number of points and standard deviation 1, separated by a distance of 10 units. Points are colored depending on which cluster they belong to.
See also
Other distill functions:
circle_data(),
cube_data(),
gaussian_data(),
grid_data(),
link_data(),
long_cluster_data(),
long_gaussian_data(),
ortho_curve(),
random_circle_cluster_data(),
random_circle_data(),
random_jump(),
random_walk(),
simplex_data(),
subset_clusters_data(),
three_clusters_data(),
trefoil_data(),
two_different_clusters_data(),
unlink_data()
Examples
df <- two_clusters_data(n = 50, dim = 2)
# two clusters with 10 members each, first 10 sampled from a 3D gaussian,
# second 10 are sampled from a 4D gaussian
df <- two_clusters_data(n = 10, dim = c(3, 4))