Skip to contents

Two gaussians with equal size but unequal bandwidths, from "How to Use t-SNE Effectively".

Usage

two_different_clusters_data(n, dim = 50, scale = 10)

Arguments

n

Number of points per gaussian.

dim

Dimension of the gaussians.

scale

Amount to reduce the standard deviation of the second cluster, relative to the first.

Value

Data frame with coordinates in the X1, X2 ... Xdim columns, and color in the color column.

Details

Creates a dataset consisting of two symmetric gaussian distributions with equal number of points, but different standard deviations: the standard deviations of the second cluster will be 1/scale of the other. Clusters are separated by 20 units. Points are colored depending on which cluster they belong to.

Examples

df <- two_different_clusters_data(n = 50, dim = 2, scale = 5)