Skip to contents

Points sampled from two unlinked circles, from "How to Use t-SNE Effectively".

Usage

unlink_data(n)

Arguments

n

Number of points to sample.

Value

Data frame with coordinates in the x, y, z columns, and color in the color column.

Details

Creates a 3D dataset where points are uniformly sampled from two (2D) circles of unit radius, separated by 3 units. The two circles are not co-planar. Points are colored depending from which circle they are sampled from.

For the linked version, see link_data().

Examples

df <- unlink_data(n = 50)