2D circle data with uniform spacing from "How to Use t-SNE Effectively".
Value
Data frame with x and y coordinates in the columns x and
y respectively, and color in the color column.
Details
Creates a dataset where the points are located on the circumference of a circle of unit radius, where the angle subtended by the point at the center of the circle has been uniformly sampled. Each point has a color linearly mapped from the angle to a rainbow color scheme.
See also
Other distill functions:
cube_data(),
gaussian_data(),
grid_data(),
link_data(),
long_cluster_data(),
long_gaussian_data(),
ortho_curve(),
random_circle_cluster_data(),
random_circle_data(),
random_jump(),
random_walk(),
simplex_data(),
subset_clusters_data(),
three_clusters_data(),
trefoil_data(),
two_clusters_data(),
two_different_clusters_data(),
unlink_data()