Random points sampled from a cube, from "How to Use t-SNE Effectively".
Details
Create a dataset of the of points randomly sampled from a unit cube of the specified dimension.
See also
Other distill functions:
circle_data(),
gaussian_data(),
grid_data(),
link_data(),
long_cluster_data(),
long_gaussian_data(),
ortho_curve(),
random_circle_cluster_data(),
random_circle_data(),
random_jump(),
random_walk(),
simplex_data(),
subset_clusters_data(),
three_clusters_data(),
trefoil_data(),
two_clusters_data(),
two_different_clusters_data(),
unlink_data()