Download the original Swiss-roll dataset used in Isomap examples.
Format
A data frame with 20,000 rows and 6 variables:
x,y,z: Coordinates of the points in the rolled three-dimensional space.u,v: Coordinates of the points in the unrolled two-dimensional space.color: A string representing a color in hex format, generated fromu.
Details
The live MIT URL for this dataset is no longer available, so the default URL uses an archived copy from the Internet Archive.
Note
Requires the R.matlab package to be installed.
References
Tenenbaum, J. B., de Silva, V., & Langford, J. C. (2000). A global geometric framework for nonlinear dimensionality reduction. Science, 290(5500), 2319-2323.
Examples
if (FALSE) { # \dontrun{
swiss <- download_isomap_swiss_roll()
plot(swiss$x, swiss$y, col = swiss$color, pch = 20, cex = 0.1)
} # }