Downloads the 50,000 point 'Mammoth' dataset, a 3D point cloud of a mammoth skeleton.
Format
A data frame with 50,000 rows and 3 variables, X, Y, and Z.
The source coordinate vectors are ordered Y, X, Z; this function reorders
them to the canonical X, Y, Z order. The Z-coordinate is the "height",
i.e. the height of the mammoth varies with Z.
For more information see https://pair-code.github.io/understanding-umap/.
Details
Downloads a data frame containing the 50,000 3D coordinates of a mammoth skeleton, digitized by the Smithsonian Institution.
This dataset is from Understanding UMAP, based on work originally done by Max Noichl. 50,000 points were down-sampled from the raw data used by Max Noichl.
Note
Requires the rjson package to be installed.
See also
Max Noichl's page: https://github.com/MNoichl/UMAP-examples-mammoth-.
Understanding UMAP: https://pair-code.github.io/understanding-umap/.
The Smithsonian page: https://3d.si.edu/object/3d/mammuthus-primigenius-blumbach:341c96cd-f967-4540-8ed1-d3fc56d31f12.
download_mammoth10k()to download a 10,000 point random sub-sample of this data.
Examples
if (FALSE) { # \dontrun{
mammoth <- download_mammoth50k()
# The mammoth in profile, facing left
plot(mammoth$X, mammoth$Z)
} # }