2D grid data from "How to Use t-SNE Effectively".
Value
Data frame with coordinates in the x and y columns,
and a per-point color in the color column.
Details
Creates a two-dimensional square grid with equal spacing between points.
Point color goes from dark to light with increasing x coordinate and
from green to blue with increasing y.
See also
Other distill functions:
circle_data(),
cube_data(),
gaussian_data(),
link_data(),
long_cluster_data(),
long_gaussian_data(),
ortho_curve(),
random_circle_cluster_data(),
random_circle_data(),
random_jump(),
random_walk(),
simplex_data(),
subset_clusters_data(),
three_clusters_data(),
trefoil_data(),
two_clusters_data(),
two_different_clusters_data(),
unlink_data()