Two long, linear clusters in 2D from "How to Use t-SNE Effectively".
Details
Creates a 2D dataset where points are sampled from two long, linear, closely-separated clusters. Points are colored depending from which cluster they are sampled from.
See also
Other distill functions:
circle_data(),
cube_data(),
gaussian_data(),
grid_data(),
link_data(),
long_gaussian_data(),
ortho_curve(),
random_circle_cluster_data(),
random_circle_data(),
random_jump(),
random_walk(),
simplex_data(),
subset_clusters_data(),
three_clusters_data(),
trefoil_data(),
two_clusters_data(),
two_different_clusters_data(),
unlink_data()