Points related by mutually orthogonal steps, from "How to Use t-SNE Effectively".
Details
Creates N points from an N-dimensional space, where each point is related by a mutually orthogonal step. Coordinates from a triangular matrix, where the coordinates in the triangle are one, and are zero everywhere else. Points are linearly mapped from their row id to a rainbow color scheme.
See also
Other distill functions:
circle_data(),
cube_data(),
gaussian_data(),
grid_data(),
link_data(),
long_cluster_data(),
long_gaussian_data(),
random_circle_cluster_data(),
random_circle_data(),
random_jump(),
random_walk(),
simplex_data(),
subset_clusters_data(),
three_clusters_data(),
trefoil_data(),
two_clusters_data(),
two_different_clusters_data(),
unlink_data()