Clusters arranged in a circle from "How to Use t-SNE Effectively".
Value
Data frame with x and y coordinates in the columns x and
y respectively, and color in the color column.
Details
Creates a dataset where the points are located on the circumference of a
circle of unit radius via circle_data(), where the
angle subtended by the point at the center of the circle has been uniformly
sampled.
Each point is then replicated 20 times, with a slight perturbation to the original coordinate (using a normal distribution with a standard deviation of 0.1). Only the twenty jittered points are added to the data frame. Each point has a color linearly mapped from the angle of the original unjittered point to a rainbow color scheme.
See also
Other distill functions:
circle_data(),
cube_data(),
gaussian_data(),
grid_data(),
link_data(),
long_cluster_data(),
long_gaussian_data(),
ortho_curve(),
random_circle_data(),
random_jump(),
random_walk(),
simplex_data(),
subset_clusters_data(),
three_clusters_data(),
trefoil_data(),
two_clusters_data(),
two_different_clusters_data(),
unlink_data()