Simulation data from a random walk process, from "How to Use t-SNE Effectively".
Details
Creates a dataset where the coordinate of each point is related to the previous point by a gaussian perturbation. Points are linearly mapped from their position in the walk to a rainbow color scheme.
See also
Other distill functions:
circle_data(),
cube_data(),
gaussian_data(),
grid_data(),
link_data(),
long_cluster_data(),
long_gaussian_data(),
ortho_curve(),
random_circle_cluster_data(),
random_circle_data(),
random_jump(),
simplex_data(),
subset_clusters_data(),
three_clusters_data(),
trefoil_data(),
two_clusters_data(),
two_different_clusters_data(),
unlink_data()