Simulation data randomly sampled from an S-shaped curve with a hole.
Value
Data frame with x, y, z columns containing the
coordinates of the points and color the RGB color.
Details
Creates a series of points sampled from an S-shaped curve in 3D, with optional normally-distributed noise. The S shape is oriented such that you should be able to see it if you plot the X and Z columns. There is a circular hole in the middle of the curve, centered at Y = 1.
Points are colored based on their distance along the curve.
This data set is based on s_curve() and is used to assess the
behavior of the PaCMAP method of Wang and co-workers (2021).
References
Wang, Y., Huang, H., Rudin, C., & Shaposhnik, Y. (2021). Understanding how dimension reduction tools work: an empirical approach to deciphering t-SNE, UMAP, TriMAP, and PaCMAP for data visualization. J Mach. Learn. Res, 22, 1-73.
See also
the PaCMAP homepage.