Data in a rough simplex from "How to Use t-SNE Effectively".
Details
Create a dataset of the specified number of points arranged in a rough simplex, which also determines the dimensionality of the dataset. Each point has a single non-zero coordinate in a different column to all the other points.
See also
Other distill functions:
circle_data(),
cube_data(),
gaussian_data(),
grid_data(),
link_data(),
long_cluster_data(),
long_gaussian_data(),
ortho_curve(),
random_circle_cluster_data(),
random_circle_data(),
random_jump(),
random_walk(),
subset_clusters_data(),
three_clusters_data(),
trefoil_data(),
two_clusters_data(),
two_different_clusters_data(),
unlink_data()