Three Gaussian Clusters With Equal Standard Deviations
Source:R/misread-tsne.R
three_clusters_data.RdThree gaussian clusters with equal size and bandwidth from "How to Use t-SNE Effectively".
Details
Creates a dataset consisting of three symmetric gaussian distributions with equal number of points and standard deviation 1. The clusters are arranged in a line, with the second cluster 10 units from the first, and the third cluster 50 units from the first. Points are colored depending on which cluster they belong to.
See also
Other distill functions:
circle_data(),
cube_data(),
gaussian_data(),
grid_data(),
link_data(),
long_cluster_data(),
long_gaussian_data(),
ortho_curve(),
random_circle_cluster_data(),
random_circle_data(),
random_jump(),
random_walk(),
simplex_data(),
subset_clusters_data(),
trefoil_data(),
two_clusters_data(),
two_different_clusters_data(),
unlink_data()