Two Gaussian Clusters With Unequal Standard Deviations
Source:R/misread-tsne.R
two_different_clusters_data.RdTwo gaussians with equal size but unequal bandwidths, from "How to Use t-SNE Effectively".
Details
Creates a dataset consisting of two symmetric gaussian distributions with
equal number of points, but different standard deviations: the standard
deviations of the second cluster will be 1/scale of the other.
Clusters are separated by 20 units. Points are colored depending on which
cluster they belong to.
See also
Other distill functions:
circle_data(),
cube_data(),
gaussian_data(),
grid_data(),
link_data(),
long_cluster_data(),
long_gaussian_data(),
ortho_curve(),
random_circle_cluster_data(),
random_circle_data(),
random_jump(),
random_walk(),
simplex_data(),
subset_clusters_data(),
three_clusters_data(),
trefoil_data(),
two_clusters_data(),
unlink_data()