Points sampled from two unlinked circles, from "How to Use t-SNE Effectively".
Details
Creates a 3D dataset where points are uniformly sampled from two (2D) circles of unit radius, separated by 3 units. The two circles are not co-planar. Points are colored depending from which circle they are sampled from.
For the linked version, see link_data().
See also
Other distill functions:
circle_data(),
cube_data(),
gaussian_data(),
grid_data(),
link_data(),
long_cluster_data(),
long_gaussian_data(),
ortho_curve(),
random_circle_cluster_data(),
random_circle_data(),
random_jump(),
random_walk(),
simplex_data(),
subset_clusters_data(),
three_clusters_data(),
trefoil_data(),
two_clusters_data(),
two_different_clusters_data()